@@ -32,6 +32,7 @@
 #include "mgl2/mgl.h"
 #include "mgl2/font.h"
 #include "mgl2/eval.h"
+#include "mgl2/evalc.h"
 //-----------------------------------------------------------------------------
 void smgl_fexport(mglGraph *gr);	// test file export
 void MGL_EXPORT mgl_create_cpp_font(HMGL gr, const wchar_t *how);
@@ -74,6 +75,7 @@ void save(mglGraph *gr,const char *name,const char *suf);
 void test(mglGraph *gr)
 {
 	mglParse par;
+	par.Execute(gr,"new f 100 'x^3':save f 'test.dat':axis:box:fplot ':test.dat:-1:1'");
 	par.Execute(gr,"text 0 0 'ab' '@'");
 //	par.Execute(gr,"new a 3 3 'x*y'\nsubplot 2 1 0 '':dens a:dens a 'k+/'\n"
 //	"subplot 2 1 1 '':mask '+' 'ff00182424f800' 30:dens a '3+'");
@@ -112,11 +114,10 @@ void mgl_generate_texi()
 	FILE *fs = fopen("wnd_samples.cpp","r");
 	while(!feof(fs))
 	{
-		fgets(buf,512,fs);
-		if(strstr(buf,"void mgls_prepare1d"))	break;
+		if(!fgets(buf,512,fs) || strstr(buf,"void mgls_prepare1d"))	break;
 	}
 	while(!feof(fs))
-	{	fprintf(fp,"%s",buf);	fgets(buf,512,fs);	}
+	{	fprintf(fp,"%s",buf);	if(!fgets(buf,512,fs))	break;	}
 	fprintf(fp,"\n@end verbatim\n@end ifclear\n\n@external{}\n");
 	fclose(fs);
 
@@ -140,11 +141,11 @@ void mgl_generate_texi()
 		fseek(fs,0,SEEK_SET);
 		snprintf(name, 64, "void smgl_%s", samp[i].name);
 		while(!feof(fs))
-		{	fgets(buf,512,fs);	if(strstr(buf,name))	break;	}
+		{	if(!fgets(buf,512,fs) || strstr(buf,name))	break;	}
 		while(!feof(fs))
 		{
-			fprintf(fp,"%s",buf);	fgets(buf,512,fs);
-			if(*buf=='}')	break;
+			fprintf(fp,"%s",buf);
+			if(!fgets(buf,512,fs) || *buf=='}')	break;
 		}
 		fprintf(fp,"}\n@end verbatim\n@end ifclear\n@pfig{%s, Sample @samp{%s}}\n@external{}\n", samp[i].name, samp[i].name);
 	}
@@ -384,7 +385,7 @@ int main(int argc,char **argv)
 		{
 			char buf[128];
 			while(!feof(fi))
-			{	fgets(buf,128,fi);	
+			{	if(!fgets(buf,128,fi))	break;
 				if(!strstr(buf,"model name"))
 				{	fprintf(fp,"@c %s\n",buf);	break;	}	}
 			fclose(fi);
