@@ -40,9 +40,9 @@ void MGL_EXPORT mgl_fft_freq(double *freq,long nn);
 /// Remove double spaces from the string
 void MGL_EXPORT mgl_strcls(char *str);
 /// Get position of substring or return -1 if not found
-long MGL_EXPORT mgl_strpos(const char *str,char *fnd);
+long MGL_EXPORT_PURE mgl_strpos(const char *str,char *fnd);
 /// Get position of symbol or return -1 if not found
-long MGL_EXPORT mgl_chrpos(const char *str,char fnd);
+long MGL_EXPORT_PURE mgl_chrpos(const char *str,char fnd);
 
 /// Get uncommented string from file (NOTE: it is not thread safe!!!)
 MGL_EXPORT char *mgl_fgetstr(FILE *fp);
@@ -56,6 +56,8 @@ void MGL_EXPORT mgl_test(const char *str, ...);
 void MGL_EXPORT mgl_info(const char *str, ...);
 /// Locate next data block (block started by -----)
 MGL_EXPORT FILE *mgl_next_data(const char *fname,int p);
+/// Enable executing MGL script if mgl_fgetstr() meet '#MGL fname.mgl [args]. Default value is 0 (false).
+void MGL_EXPORT mgl_fgetstr_mgl(int enable);
 
 #ifdef __cplusplus
 }
