@@ -552,6 +552,7 @@ public:
 	bool CopyProj(mglPnt &q, long from, mglPoint p, mglPoint n, short sub=0);
 	void CopyProj(long id, long from, mglPoint p, mglPoint n, short sub=0)
 	{	if(id>=0)	CopyProj(Pnt[id],from,p,n,sub);	}
+	void DisablePnt(long id)	{	Pnt[id].x = NAN;	}
 	void SetRGBA(long k, const mglColor &c)
 	{	if(k>=0)	{mglPnt &p=Pnt[k];	p.r = c.r;	p.g = c.g;	p.b = c.b;	p.a = c.a;}	}
 	virtual void Reserve(long n);	///< Allocate n-cells for Pnt and return current position
@@ -609,7 +610,8 @@ public:
 
 	/// Get color depending on single variable z, which should be scaled if scale=true
 	inline mreal GetC(long s,mreal z,bool scale = true) const
-	{	return s+(scale?GetA(z):(z>0?z/MGL_FEPSILON:0));	}
+	{	return s+(scale?GetA(z):(z<0?0:z/MGL_FEPSILON));	}
+//	{	return s+(scale?GetA(z):(z>0?z/MGL_FEPSILON:0));	}
 	/// Get alpha value depending on single variable a
 	mreal GetA(mreal a) const MGL_FUNC_PURE;
 	/// Set pen/palette
