@@ -332,17 +332,17 @@ MGL_EXPORT const unsigned char *mgl_get_rgba(HMGL gr);
 MGL_EXPORT const unsigned char *mgl_get_rgba_(uintptr_t *gr);
 /// Get RGBA values of background image
 /** Position of element {i,j} is [4*i + 4*Width*j]. */
-MGL_EXPORT const unsigned char *mgl_get_background(HMGL gr);
-MGL_EXPORT const unsigned char *mgl_get_background_(uintptr_t *gr);
+MGL_EXPORT_PURE const unsigned char *mgl_get_background(HMGL gr);
+MGL_EXPORT_PURE const unsigned char *mgl_get_background_(uintptr_t *gr);
 /// Set object/subplot id
 void MGL_EXPORT mgl_set_obj_id(HMGL gr, int id);
 void MGL_EXPORT mgl_set_obj_id_(uintptr_t *gr, int *id);
 /// Get object id
-int MGL_EXPORT mgl_get_obj_id(HMGL gr, int x, int y);
-int MGL_EXPORT mgl_get_obj_id_(uintptr_t *gr, int *x, int *y);
+int MGL_EXPORT_PURE mgl_get_obj_id(HMGL gr, int x, int y);
+int MGL_EXPORT_PURE mgl_get_obj_id_(uintptr_t *gr, int *x, int *y);
 /// Get subplot id
-int MGL_EXPORT mgl_get_spl_id(HMGL gr, int x, int y);
-int MGL_EXPORT mgl_get_spl_id_(uintptr_t *gr, int *x, int *y);
+int MGL_EXPORT_PURE mgl_get_spl_id(HMGL gr, int x, int y);
+int MGL_EXPORT_PURE mgl_get_spl_id_(uintptr_t *gr, int *x, int *y);
 /// Get width of the image
 int MGL_EXPORT mgl_get_width(HMGL gr);
 int MGL_EXPORT mgl_get_width_(uintptr_t *gr);
@@ -356,8 +356,8 @@ void MGL_EXPORT mgl_calc_xyz_(uintptr_t *gr, int *xs, int *ys, mreal *x, mreal *
 void MGL_EXPORT mgl_calc_scr(HMGL gr, double x, double y, double z, int *xs, int *ys);
 void MGL_EXPORT mgl_calc_scr_(uintptr_t *gr, mreal *x, mreal *y, mreal *z, int *xs, int *ys);
 /// Check if {xs,ys} is close to active point with accuracy d, and return its position or -1
-long MGL_EXPORT mgl_is_active(HMGL gr, int xs, int ys, int d);
-long MGL_EXPORT mgl_is_active_(uintptr_t *gr, int *xs, int *ys, int *d);
+long MGL_EXPORT_PURE mgl_is_active(HMGL gr, int xs, int ys, int d);
+long MGL_EXPORT_PURE mgl_is_active_(uintptr_t *gr, int *xs, int *ys, int *d);
 
 /// Create new frame.
 int MGL_EXPORT mgl_new_frame(HMGL gr);
@@ -366,8 +366,8 @@ int MGL_EXPORT mgl_new_frame_(uintptr_t *gr);
 void MGL_EXPORT mgl_end_frame(HMGL gr);
 void MGL_EXPORT mgl_end_frame_(uintptr_t *gr);
 /// Get the number of created frames
-int MGL_EXPORT mgl_get_num_frame(HMGL gr);
-int MGL_EXPORT mgl_get_num_frame_(uintptr_t *gr);
+int MGL_EXPORT_PURE mgl_get_num_frame(HMGL gr);
+int MGL_EXPORT_PURE mgl_get_num_frame_(uintptr_t *gr);
 /// Reset frames counter (start it from zero)
 void MGL_EXPORT mgl_reset_frames(HMGL gr);
 void MGL_EXPORT mgl_reset_frames_(uintptr_t *gr);
@@ -462,7 +462,7 @@ void MGL_EXPORT mgl_subplot_(uintptr_t *gr, int *nx,int *ny,int *m, const char *
  *  '_' for reserving space at bottom
  *  '#' for using whole region. */
 void MGL_EXPORT mgl_subplot_d(HMGL gr, int nx,int ny,int m,const char *style, double dx, double dy);
-void MGL_EXPORT mgl_subplot_d_(uintptr_t *gr, int *nx,int *ny,int *m, mreal *dx, mreal *dy);
+void MGL_EXPORT mgl_subplot_d_(uintptr_t *gr, int *nx,int *ny,int *m,const char *style, mreal *dx, mreal *dy,int l);
 /// Put further plotting in rectangle of dx*dy cells starting from m-th cell of nx*ny grid of the image.
 /** String \a style may contain:
  *  '<' for reserving space at left
@@ -534,65 +534,7 @@ void MGL_EXPORT mgl_zoom(HMGL gr, double x1, double y1, double x2, double y2);
 void MGL_EXPORT mgl_zoom_(uintptr_t *gr, mreal *x1, mreal *y1, mreal *x2, mreal *y2);
 
 //-----------------------------------------------------------------------------
-/// Callback function for mouse click
-void MGL_EXPORT mgl_set_click_func(HMGL gr, void (*func)(void *p));
-#if MGL_HAVE_PTHR_WIDGET
-/// Mutex for lock/unlock by widget
-void MGL_EXPORT mgl_wnd_set_mutex(HMGL gr, pthread_mutex_t *mutex);
-#endif
 
-/// Make custom dialog for parameters ids of element properties defined by args
-void MGL_EXPORT mgl_wnd_make_dialog(HMGL gr, const char *ids, char const * const *args, const char *title);
-/// Set callback functions for drawing and data reloading
-void MGL_EXPORT mgl_wnd_set_func(HMGL gr, int (*draw)(HMGL gr, void *p), void *par, void (*reload)(void *p));
-/// Set callback functions for setting properties
-void MGL_EXPORT mgl_wnd_set_prop(HMGL gr, void (*prop)(char id, const char *val, void *p), void *par);
-/// Set delay for animation in seconds
-void MGL_EXPORT mgl_wnd_set_delay(HMGL gr, double dt);
-void MGL_EXPORT mgl_wnd_set_delay_(uintptr_t *gr, mreal *dt);
-/// Get delay for animation in seconds
-double MGL_EXPORT mgl_wnd_get_delay(HMGL gr);
-double MGL_EXPORT mgl_wnd_get_delay_(uintptr_t *gr);
-/// Set window properties
-void MGL_EXPORT mgl_setup_window(HMGL gr, int clf_upd, int showpos);
-void MGL_EXPORT mgl_setup_window_(uintptr_t *gr, int *clf_upd, int *showpos);
-/// Switch on/off transparency (do not overwrite user settings)
-void MGL_EXPORT mgl_wnd_toggle_alpha(HMGL gr);
-void MGL_EXPORT mgl_wnd_toggle_alpha_(uintptr_t *gr);
-/// Switch on/off lighting (do not overwrite user settings)
-void MGL_EXPORT mgl_wnd_toggle_light(HMGL gr);
-void MGL_EXPORT mgl_wnd_toggle_light_(uintptr_t *gr);
-/// Switch on/off zooming by mouse
-void MGL_EXPORT mgl_wnd_toggle_zoom(HMGL gr);
-void MGL_EXPORT mgl_wnd_toggle_zoom_(uintptr_t *gr);
-/// Switch on/off rotation by mouse
-void MGL_EXPORT mgl_wnd_toggle_rotate(HMGL gr);
-void MGL_EXPORT mgl_wnd_toggle_rotate_(uintptr_t *gr);
-/// Switch off all zooming and rotation
-void MGL_EXPORT mgl_wnd_toggle_no(HMGL gr);
-void MGL_EXPORT mgl_wnd_toggle_no_(uintptr_t *gr);
-/// Update picture by calling user drawing function
-void MGL_EXPORT mgl_wnd_update(HMGL gr);
-void MGL_EXPORT mgl_wnd_update_(uintptr_t *gr);
-/// Reload user data and update picture
-void MGL_EXPORT mgl_wnd_reload(HMGL gr);
-void MGL_EXPORT mgl_wnd_reload_(uintptr_t *gr);
-/// Adjust size of bitmap to window size
-void MGL_EXPORT mgl_wnd_adjust(HMGL gr);
-void MGL_EXPORT mgl_wnd_adjust_(uintptr_t *gr);
-/// Show next frame (if one)
-void MGL_EXPORT mgl_wnd_next_frame(HMGL gr);
-void MGL_EXPORT mgl_wnd_next_frame_(uintptr_t *gr);
-/// Show previous frame (if one)
-void MGL_EXPORT mgl_wnd_prev_frame(HMGL gr);
-void MGL_EXPORT mgl_wnd_prev_frame_(uintptr_t *gr);
-/// Run slideshow (animation) of frames
-void MGL_EXPORT mgl_wnd_animation(HMGL gr);
-void MGL_EXPORT mgl_wnd_animation_(uintptr_t *gr);
-/// Get last mouse position
-void MGL_EXPORT mgl_get_last_mouse_pos(HMGL gr, mreal *x, mreal *y, mreal *z);
-void MGL_EXPORT mgl_get_last_mouse_pos_(uintptr_t *gr, mreal *x, mreal *y, mreal *z);
-//-----------------------------------------------------------------------------
 /// Create HMPR object for parsing MGL scripts
 HMPR MGL_EXPORT mgl_create_parser();
 uintptr_t MGL_EXPORT mgl_create_parser_();
@@ -614,24 +556,24 @@ uintptr_t MGL_EXPORT mgl_parser_add_var_(uintptr_t* p, const char *name, int);
 MGL_EXPORT mglDataA *mgl_parser_add_varw(HMPR p, const wchar_t *name);
 /// Find variable with given name or return NULL if no one
 /// NOTE !!! You must not delete obtained data arrays !!!
-MGL_EXPORT mglDataA *mgl_parser_find_var(HMPR p, const char *name);
+MGL_EXPORT_PURE mglDataA *mgl_parser_find_var(HMPR p, const char *name);
 uintptr_t MGL_EXPORT mgl_parser_find_var_(uintptr_t* p, const char *name, int);
-MGL_EXPORT mglDataA *mgl_parser_find_varw(HMPR p, const wchar_t *name);
+MGL_EXPORT_PURE mglDataA *mgl_parser_find_varw(HMPR p, const wchar_t *name);
 /// Get variable with given id
 /// NOTE !!! You must not delete obtained data arrays !!!
-MGL_EXPORT mglDataA *mgl_parser_get_var(HMPR p, unsigned long id);
-uintptr_t MGL_EXPORT mgl_parser_get_var_(uintptr_t* p, unsigned long *id);
+MGL_EXPORT_PURE mglDataA *mgl_parser_get_var(HMPR p, unsigned long id);
+uintptr_t MGL_EXPORT_PURE mgl_parser_get_var_(uintptr_t* p, unsigned long *id);
 /// Get number of variables
-long MGL_EXPORT mgl_parser_num_var(HMPR p);
-long MGL_EXPORT mgl_parser_num_var_(uintptr_t* p);
+long MGL_EXPORT_PURE mgl_parser_num_var(HMPR p);
+long MGL_EXPORT_PURE mgl_parser_num_var_(uintptr_t* p);
 
 /// Get constant with given id
 /// NOTE !!! You must not delete obtained data arrays !!!
-MGL_EXPORT mglNum *mgl_parser_get_const(HMPR p, unsigned long id);
-uintptr_t MGL_EXPORT mgl_parser_get_const_(uintptr_t* p, unsigned long *id);
+MGL_EXPORT_PURE mglNum *mgl_parser_get_const(HMPR p, unsigned long id);
+uintptr_t MGL_EXPORT_PURE mgl_parser_get_const_(uintptr_t* p, unsigned long *id);
 /// Get number of constants
-long MGL_EXPORT mgl_parser_num_const(HMPR p);
-long MGL_EXPORT mgl_parser_num_const_(uintptr_t* p);
+long MGL_EXPORT_PURE mgl_parser_num_const(HMPR p);
+long MGL_EXPORT_PURE mgl_parser_num_const_(uintptr_t* p);
 
 /// Delete variable with name
 void MGL_EXPORT mgl_parser_del_var(HMPR p, const char *name);
@@ -692,16 +634,16 @@ void MGL_EXPORT mgl_parser_start_id_(uintptr_t* p, int *id);
 ///		3 - setup, 4 - data handle, 5 - data create, 6 - subplot, 7 - program
 ///		8 - 1d plot, 9 - 2d plot, 10 - 3d plot, 11 - dd plot, 12 - vector plot
 ///		13 - axis, 14 - primitives, 15 - axis setup, 16 - text/legend, 17 - data transform
-int MGL_EXPORT mgl_parser_cmd_type(HMPR pr, const char *name);
-int MGL_EXPORT mgl_parser_cmd_type_(uintptr_t* p, const char *name, int);
+int MGL_EXPORT_PURE mgl_parser_cmd_type(HMPR pr, const char *name);
+int MGL_EXPORT_PURE mgl_parser_cmd_type_(uintptr_t* p, const char *name, int);
 /// Return description of MGL command
-MGL_EXPORT const char *mgl_parser_cmd_desc(HMPR pr, const char *name);
+MGL_EXPORT_PURE const char *mgl_parser_cmd_desc(HMPR pr, const char *name);
 /// Return string of command format (command name and its argument[s])
-MGL_EXPORT const char *mgl_parser_cmd_frmt(HMPR pr, const char *name);
+MGL_EXPORT_PURE const char *mgl_parser_cmd_frmt(HMPR pr, const char *name);
 /// Get name of command with number n
-MGL_EXPORT const char *mgl_parser_cmd_name(HMPR pr, long id);
+MGL_EXPORT_PURE const char *mgl_parser_cmd_name(HMPR pr, long id);
 /// Get number of defined commands
-long MGL_EXPORT mgl_parser_cmd_num(HMPR pr);
+long MGL_EXPORT_PURE mgl_parser_cmd_num(HMPR pr);
 
 /// Return result of formula evaluation
 HMDT MGL_EXPORT mgl_parser_calc(HMPR pr, const char *formula);
