@@ -25,9 +25,9 @@
 //-----------------------------------------------------------------------------
 #include <stdarg.h>
 //-----------------------------------------------------------------------------
-mreal MGL_EXPORT mglLinear(const mreal *a, long nx, long ny, long nz, mreal x, mreal y, mreal z);
+mreal MGL_EXPORT_PURE mglLinear(const mreal *a, long nx, long ny, long nz, mreal x, mreal y, mreal z);
 mreal MGL_EXPORT mglSpline3(const mreal *a, long nx, long ny, long nz, mreal x, mreal y, mreal z,mreal *dx=0, mreal *dy=0, mreal *dz=0);
-mreal MGL_EXPORT mglSpline3s(const mreal *a, long nx, long ny, long nz, mreal x, mreal y, mreal z);
+mreal MGL_EXPORT_PURE mglSpline3s(const mreal *a, long nx, long ny, long nz, mreal x, mreal y, mreal z);
 //-----------------------------------------------------------------------------
 /// Class for working with data array
 class MGL_EXPORT mglData : public mglDataA
@@ -279,6 +279,9 @@ using mglDataA::Momentum;
 	{	return mglData(true,mgl_data_section(this,&ids,dir,val));	}
 	inline mglData Section(long id, char dir='y', mreal val=NAN) const
 	{	return mglData(true,mgl_data_section_val(this,id,dir,val));	}
+	/// Get contour lines for dat[i,j]=val. NAN values separate the the curves.
+	inline mglData Conts(mreal val)
+	{	return mglData(true,mgl_data_conts(val,this));	}
 
 	/// Get trace of the data array
 	inline mglData Trace() const
@@ -298,6 +301,9 @@ using mglDataA::Momentum;
 	/// Get array which is result of minimal values in given direction or directions
 	inline mglData Min(const char *dir) const
 	{	return mglData(true,mgl_data_min_dir(this,dir));	}
+	/// Get positions of local maximums and minimums
+	inline mglData MinMax() const
+	{	return mglData(true,mgl_data_minmax(this));	}
 	/// Get the data which is direct multiplication (like, d[i,j] = this[i]*a[j] and so on)
 	inline mglData Combine(const mglDataA &dat) const
 	{	return mglData(true,mgl_data_combine(this,&dat));	}
@@ -451,6 +457,15 @@ using mglDataA::Momentum;
 	/// Direct access to the data cell
 	inline mreal operator[](long i) const	{	return a[i];	}
 	inline mreal &operator[](long i)		{	return a[i];	}
+	/// Get sub-array of the data with given fixed indexes
+	inline mglData operator()(long xx,long yy=-1,long zz=-1) const
+	{	return mglData(true,mgl_data_subdata(this,xx,yy,zz));	}
+	inline mglData operator()(const mglDataA &xx, const mglDataA &yy, const mglDataA &zz) const
+	{	return mglData(true,mgl_data_subdata_ext(this,&xx,&yy,&zz));	}
+	inline mglData operator()(const mglDataA &xx, const mglDataA &yy) const
+	{	return mglData(true,mgl_data_subdata_ext(this,&xx,&yy,0));	}
+	inline mglData operator()(const mglDataA &xx) const
+	{	return mglData(true,mgl_data_subdata_ext(this,&xx,0,0));	}
 #endif
 
 #ifndef DEBUG
