@@ -40,7 +40,7 @@ extern "C" {
 #endif
 /// Get integer power of x
 double MGL_EXPORT_CONST mgl_ipow(double x,int n);
-double MGL_EXPORT mgl_ipow_(mreal *x,int *n);
+double MGL_EXPORT_PURE mgl_ipow_(mreal *x,int *n);
 /// Get number of seconds since 1970 for given string
 double MGL_EXPORT mgl_get_time(const char *time, const char *fmt);
 double MGL_EXPORT mgl_get_time_(const char *time, const char *fmt,int,int);
@@ -169,6 +169,8 @@ uintptr_t MGL_EXPORT mgl_data_section_(uintptr_t *d, uintptr_t *ids, const char
 /** If section id is negative then reverse order is used (i.e. -1 give last section). */
 HMDT MGL_EXPORT mgl_data_section_val(HCDT dat, long id, char dir, mreal val);
 uintptr_t MGL_EXPORT mgl_data_section_val_(uintptr_t *d, int *id, const char *dir, mreal *val,int);
+/// Get contour lines for dat[i,j]=val. NAN values separate the the curves
+HMDT mgl_data_conts(mreal val, HCDT dat);
 
 /// Equidistantly fill the data to range [x1,x2] in direction dir
 void MGL_EXPORT mgl_data_fill(HMDT dat, mreal x1,mreal x2,char dir);
@@ -273,7 +275,7 @@ uintptr_t MGL_EXPORT mgl_data_tridmat_(uintptr_t *A, uintptr_t *B, uintptr_t *C,
 /// Returns pointer to data element [i,j,k]
 MGL_EXPORT mreal *mgl_data_value(HMDT dat, long i,long j,long k);
 /// Returns pointer to internal data array
-MGL_EXPORT mreal *mgl_data_data(HMDT dat);
+MGL_EXPORT_PURE mreal *mgl_data_data(HMDT dat);
 
 /// Gets the x-size of the data.
 long MGL_EXPORT mgl_data_get_nx(HCDT d);
@@ -319,6 +321,18 @@ uintptr_t MGL_EXPORT mgl_data_max_dir_(uintptr_t *dat, const char *dir,int);
 /// Get array which is result of minimal values in given direction or directions
 HMDT MGL_EXPORT mgl_data_min_dir(HCDT dat, const char *dir);
 uintptr_t MGL_EXPORT mgl_data_min_dir_(uintptr_t *dat, const char *dir,int);
+/// Get positions of local maximums and minimums
+HMDT MGL_EXPORT mgl_data_minmax(HCDT dat);
+uintptr_t MGL_EXPORT mgl_data_minmax_(uintptr_t *dat);
+/// Get indexes of a set of connected surfaces for set of values {a_ijk,b_ijk} as dependent on j,k
+/** NOTE: not optimized for general case!!! */
+HMDT MGL_EXPORT mgl_data_connect(HCDT a, HCDT b);
+uintptr_t MGL_EXPORT mgl_data_connect_(uintptr_t *a, uintptr_t *b);
+/// Resort data values according found connected surfaces for set of values {a_ijk,b_ijk} as dependent on j,k
+/** NOTE: not optimized for general case!!! */
+void MGL_EXPORT mgl_data_connect_r(HMDT a, HMDT b);
+void MGL_EXPORT mgl_data_connect_r_(uintptr_t *a, uintptr_t *b);
+
 /// Cumulative summation the data in given direction or directions
 void MGL_EXPORT mgl_data_cumsum(HMDT dat, const char *dir);
 void MGL_EXPORT mgl_data_cumsum_(uintptr_t *dat, const char *dir,int);
