@@ -38,7 +38,7 @@ void MGL_EXPORT mgl_ask_fltk(const wchar_t *quest, wchar_t *res);
 /// FLTK function for displaying progress of something.
 void MGL_EXPORT mgl_progress_fltk(int value, int maximal, HMGL gr);
 /// Return pointer to widget (Fl_MGLView*) used for plotting
-MGL_EXPORT void *mgl_fltk_widget(HMGL gr);
+MGL_EXPORT_PURE void *mgl_fltk_widget(HMGL gr);
 #ifdef __cplusplus
 }
 //-----------------------------------------------------------------------------
@@ -65,8 +65,6 @@ public:
     virtual ~mglFLTK() {}
 	int Run()	{	return mgl_fltk_run();	}	///< Run main loop for event handling
 	int RunThr()	{	return mgl_fltk_thr();	}	///< Run main loop for event handling in separate thread
-	/// Return pointer to widget (Fl_MGLView*) used for plotting
-	void *Widget()	{	return mgl_fltk_widget(gr);	}
 };
 //-----------------------------------------------------------------------------
 #endif
