@@ -21,6 +21,7 @@
 #define _MGL_WND_H_
 
 #include "mgl2/mgl.h"
+#include "mgl2/wnd_cf.h"
 //-----------------------------------------------------------------------------
 MGL_EXPORT void *mgl_draw_calc(void *p);
 void MGL_EXPORT mgl_parse_comments(const char *text, double &a1, double &a2, double &da, std::vector<std::string> &anim, std::string &dlg_ids, std::vector<std::string> &dlg_par);
@@ -88,8 +89,14 @@ public:
 	mglWnd() : mglGraph(-1)	{}
 	virtual ~mglWnd() {	mgl_use_graph(gr,-255);	}
 	virtual int Run()=0;		///< Run main loop for event handling
-	/// Return pointer to widget used for plotting
-	virtual void *Widget()	{	return NULL;	}
+	inline void *Window()		///< Return pointer to widget (Fl_Window* or QMainWindow*) used for plotting
+	{	return mgl_wnd_window(gr);	}
+	inline void *Widget()		///< Return pointer to widget (Fl_MGLView* or QMathGL*) used for plotting
+	{	return mgl_wnd_widget(gr);	}
+	inline void WndSize(int w, int h)	///< Resize window
+	{	mgl_wnd_size(gr,w,h);	}
+	inline void WndMove(int x, int y)	///< Move window
+	{	mgl_wnd_move(gr,x,y);	}
 
 	inline void ToggleAlpha()	///< Switch on/off transparency (do not overwrite user settings)
 	{	mgl_wnd_toggle_alpha(gr);	}
