@@ -267,29 +267,6 @@ void ScriptWindow::mem_pressed(int kind)
 	mem_init();
 }
 //-----------------------------------------------------------------------------
-const char *hints[] = {
-	_("You can shift axis range by pressing middle button and moving mouse. Also, you can zoom in/out axis range by using mouse wheel."),
-	_("You can rotate/shift/zoom whole plot by mouse. Just press 'Rotate' toolbutton, click image and hold a mouse button: left button for rotation, right button for zoom/perspective, middle button for shift."),
-	_("You may quickly draw the data from file. Just use: mgllab 'filename.dat' in command line."),
-	_("You can copy the current image to clipboard by pressing Ctrl-Shift-C. Later you can paste it directly into yours document or presentation."),
-	_("You can export image into a set of format (EPS, SVG, PNG, JPEG) by pressing right mouse button inside image and selecting 'Export as ...'."),
-	_("You can setup colors for script highlighting in Property dialog. Just select menu item 'Settings/Properties'."),
-	_("You can save the parameter of animation inside MGL script by using comment started from '##a ' or '##c ' for loops."),
-	_("New drawing never clears things drawn already. For example, you can make a surface with contour lines by calling commands 'surf' and 'cont' one after another (in any order). "),
-	_("You can put several plots in the same image by help of commands 'subplot' or 'inplot'."),
-	_("All indexes (of data arrays, subplots and so on) are always start from 0."),
-	_("You can edit MGL file in any text editor. Also you can run it in console by help of commands: mglconv, mglview."),
-	_("You can use command 'once on|off' for marking the block which should be executed only once. For example, this can be the block of large data reading/creating/handling. Press F9 (or menu item 'Graphics/Reload') to re-execute this block."),
-	_("You can use command 'stop' for terminating script parsing. It is useful if you don't want to execute a part of script."),
-	_("You can type arbitrary expression as input argument for data or number. In last case (for numbers), the first value of data array is used."),
-	_("There is powerful calculator with a lot of special functions. You can use buttons or keyboard to type the expression. Also you can use existed variables in the expression."),
-	_("The calculator can help you to put complex expression in the script. Just type the expression (which may depend on coordinates x,y,z and so on) and put it into the script."),
-	_("You can easily insert file or folder names, last fitted formula or numerical value of selection by using menu Edit|Insert."),
-	_("The special dialog (Edit|Insert|New Command) help you select the command, fill its arguments and put it into the script."),
-	_("You can put several plotting commands in the same line or in separate function, for highlighting all of them simultaneously."),
-	NULL
-};
-//-----------------------------------------------------------------------------
 void cb_hint_prev(Fl_Widget*,void*);
 void cb_hint_next(Fl_Widget*,void*);
 class HintDlg : public GeneralDlg
@@ -303,7 +280,7 @@ public:
 		Fl_Button *o;
 		w = new Fl_Double_Window(280, 265);	cur=0;
 		hint = new Fl_Help_View(10, 10, 260, 185);
-		hint->value(hints[0]);
+		hint->value(mgl_hints[0]);
 		start = new Fl_Check_Button(10, 200, 260, 25, _("Show hint on startup"));
 		o = new Fl_Button(10, 230, 80, 25, _("@<-  Prev"));
 		o->callback(cb_hint_prev);
@@ -319,15 +296,15 @@ public:
 	{	pref.set("show_hint",start->value());	hide();	}
 	void prev()
 	{
-		int n=0;	while(hints[n])	n++;
+		int n=0;	while(mgl_hints[n])	n++;
 		cur = cur>0?cur-1:n-1;
-		hint->value(hints[cur]);
+		hint->value(mgl_hints[cur]);
 	}
 	void next()
 	{
-		int n=0;	while(hints[n])	n++;
+		int n=0;	while(mgl_hints[n])	n++;
 		cur = cur<n-1?cur+1:0;
-		hint->value(hints[cur]);
+		hint->value(mgl_hints[cur]);
 	}
 } hint_dlg;
 //-----------------------------------------------------------------------------
