@@ -460,7 +460,7 @@ void save_dat_cb(Fl_Widget*, void*v)
 		const char *ext = fl_filename_ext(newfile);
 		if(!strcmp(ext,"h5") || !strcmp(ext,"hdf"))	// this is HDF file
 		{
-			std::string name = wcstombs(e->var->s);
+			std::string name = wcstombs(e->var->Name());
 			e->var->SaveHDF(newfile, name.c_str());
 		}
 		else	e->var->Save(newfile);
@@ -470,11 +470,11 @@ void save_dat_cb(Fl_Widget*, void*v)
 void exp_dat_cb(Fl_Widget*, void*v)
 {
 	TableWindow* e = (TableWindow*)v;
-	const char *scheme, *newfile = mgl_file_chooser(_("Export Data?"),
+	const char *newfile = mgl_file_chooser(_("Export Data?"),
 		_("PNG Files \t*.png"), true);
 	if(newfile)
 	{	// TODO show dialog for color scheme
-		scheme = fl_input(_("Enter color scheme"),MGL_DEF_SCH);
+		const char *scheme = fl_input(_("Enter color scheme"),MGL_DEF_SCH);
 		if(scheme)	e->var->Export(newfile,scheme);
 	}
 }
@@ -482,12 +482,12 @@ void exp_dat_cb(Fl_Widget*, void*v)
 void imp_dat_cb(Fl_Widget*, void*v)
 {
 	TableWindow* e = (TableWindow*)v;
-	const char *scheme, *newfile = mgl_file_chooser(_("Import Data?"),
+	const char *newfile = mgl_file_chooser(_("Import Data?"),
 		_("PNG Files \t*.png"));
 	HMDT d = dynamic_cast<HMDT>(e->var);
 	if(d && newfile)
 	{
-		scheme = fl_input(_("Enter color scheme"),MGL_DEF_SCH);
+		const char *scheme = fl_input(_("Enter color scheme"),MGL_DEF_SCH);
 		if(scheme)
 		{	d->Import(newfile,scheme);	e->refresh();	}
 	}
@@ -503,7 +503,7 @@ void list_dat_cb(Fl_Widget*, void*v)
 	{	fl_message(_("Incorrect type of base data"));	return;	}
 	if(e->var->GetNz()>1)	fl_message(_("Only current slice will be inserted"));
 
-	std::string list = "list " + wcstombs(e->var->s);
+	std::string list = "list " + wcstombs(e->var->Name());
 	long k=e->get_slice(), nx=e->var->GetNx(), ny=e->var->GetNy();
 	for(long j=0;j<ny;j++)
 	{
@@ -646,6 +646,7 @@ struct CropDlg : public GeneralDlg
 		n1=mgl_int(z1->value());	n2=mgl_int(z2->value());
 		if(d)	d->Crop(n1,n2,'z');
 		if(c)	c->Crop(n1,n2,'z');
+		hide();
 	}
 	void run(mglDataA *d)
 	{
@@ -683,6 +684,7 @@ public:
 		HADT c = dynamic_cast<HADT>(dat);
 		if(d)	d->Transpose(how->text());
 		if(c)	c->Transpose(how->text());
+		hide();
 	}
 	void run(mglDataA *d)
 	{
@@ -897,7 +899,7 @@ void TableWindow::update(mglDataA *v)
 {
 	static std::string name;
 	if(v==0)	return;
-	name = wcstombs(v->s);
+	name = wcstombs(v->Name());
 	w->label(name.c_str());
 	v->func = delete_cb;
 	if(var)	var->o = 0;
