@@ -391,11 +391,11 @@ bool mglBase::AddPntQ(mglPnt &q, const mglMatrix *mat, mglPoint p, mreal c, mglP
 	// scl&8 -- bypass palette for enabling alpha
 	// scl&16 -- put points inside axis range
 	if(mgl_isnan(c) || mgl_isnan(a))	{	q.x=NAN;	return false;	}
-	bool norefr = mgl_isnan(n.x) && mgl_isnan(n.y) && !mgl_isnan(n.z);
+	bool norefr = mgl_isnan(n.x) && mgl_isnan(n.y) && !mgl_isnan(n.z), res=true;
 	if(scl>0)
 	{
 		if(scl&16)	mgl_coor_box(this, p);
-		ScalePoint(mat,p,n,!(scl&2));
+		res = ScalePoint(mat,p,n,!(scl&2));
 	}
 	if(mgl_isnan(p.x))	{	q.x=NAN;	return false;	}
 	a = (a>=0 && a<=1) ? a : AlphaDef;
@@ -434,7 +434,7 @@ bool mglBase::AddPntQ(mglPnt &q, const mglMatrix *mat, mglPoint p, mreal c, mglP
 	if(norefr)	q.v=0;
 	if(!get(MGL_ENABLE_LIGHT) && !(scl&4))	q.u=q.v=NAN;
 	q.sub=mat->norot?-1*(int)Sub.size():Sub.size()-1;
-	return true;
+	return (scl&16)?res:true;
 }
 //-----------------------------------------------------------------------------
 long mglBase::CopyNtoC(long from, mreal c)
@@ -998,7 +998,7 @@ void MGL_EXPORT mgl_chrrgb(char p, float c[3])
 		}
 }
 //-----------------------------------------------------------------------------
-size_t MGL_EXPORT mgl_get_num_color(const char *s, int smooth)
+size_t MGL_EXPORT_PURE mgl_get_num_color(const char *s, int smooth)
 {
 	if(!s || !s[0])	return 0;
 	size_t l=strlen(s), n=0;	long j=0;
@@ -1193,7 +1193,7 @@ mreal mglBase::NextColor(long id, long sh)
 	return cc;
 }
 //-----------------------------------------------------------------------------
-MGL_EXPORT const char *mglchrs(const char *str, const char *chr)
+MGL_EXPORT_PURE const char *mglchrs(const char *str, const char *chr)
 {
 	if(!str || !str[0] || !chr || !chr[0])	return NULL;
 	size_t l=strlen(chr);
@@ -1205,7 +1205,7 @@ MGL_EXPORT const char *mglchrs(const char *str, const char *chr)
 	return NULL;
 }
 //-----------------------------------------------------------------------------
-MGL_EXPORT const char *mglchr(const char *str, char ch)
+MGL_EXPORT_PURE const char *mglchr(const char *str, char ch)
 {
 	if(!str || !str[0])	return NULL;
 	size_t l=strlen(str),k=0;
@@ -1339,7 +1339,8 @@ mreal mglBase::GetA(mreal a) const
 {
 	if(fa)	a = fa->Calc(0,0,0,a);
 	a = (a-FMin.c)/(FMax.c-FMin.c);
-	a = (a<1?(a>0?a:0):1)/MGL_FEPSILON;	// for texture a must be <1 always!!!
+	a = (a>1?1:(a<0?0:a))/MGL_FEPSILON;	// for texture a must be <1 always!!!
+//	a = (a<1?(a>0?a:0):1)/MGL_FEPSILON;	// for texture a must be <1 always!!!
 	return a;
 }
 //-----------------------------------------------------------------------------
