@@ -17,6 +17,8 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
+#include <set>
+#include <stdarg.h>
 #include <ctype.h>
 #include "mgl2/data.h"
 #include "mgl2/eval.h"
@@ -472,6 +474,82 @@ uintptr_t MGL_EXPORT mgl_data_min_dir_(uintptr_t *d, const char *dir,int l)
 {	char *s=new char[l+1];	memcpy(s,dir,l);	s[l]=0;
 	uintptr_t r=uintptr_t(mgl_data_min_dir(_DT_,s));	delete []s;	return r;	}
 //-----------------------------------------------------------------------------
+HMDT MGL_EXPORT mgl_data_minmax(HCDT dat)
+{
+	long n=dat->GetNx(), m=dat->GetNy(), l=dat->GetNz();
+	std::vector<mreal> imax, jmax, kmax;
+	HMDT res=NULL;
+	if(n>3 && m==1 && l==1)
+	{
+		std::vector<mreal> imax;
+		for(long i=1;i<n-1;i++)
+		{
+			mreal v = dat->v(i);
+			if(v > dat->v(i-1) && v >= dat->v(i+1))	imax.push_back(i);
+			if(v < dat->v(i-1) && v <= dat->v(i+1))	imax.push_back(i);
+		}
+		size_t nn = imax.size();
+		if(nn>0)
+		{	res = new mglData(nn);
+			for(size_t i=0;i<nn;i++)	res->a[i] = imax[i]/(n-1.);	}
+	}
+	else if(n>3 && m>3 && l==1)
+	{
+		std::vector<mreal> imax, jmax;
+		for(long j=1;j<m-1;j++)	for(long i=1;i<n-1;i++)
+		{
+			mreal v = dat->v(i,j);
+			long di[] = {-1,0,1, -1,1, -1,0,1}, dj[] = {-1,-1, -1,0, 0,1,1,1}, vmax=0, vmin=0;
+			for(int ii=0;ii<8;ii++)
+			{
+				mreal u = dat->v(i+di[ii],j+dj[ii]);
+				if(mgl_isnan(u))	{	vmax=vmin=0;	break;	}
+				if(v < u)	vmin++;
+				if(v > u)	vmax++;
+			}
+			if(vmin>0 && vmax==0)	{	imax.push_back(i);	jmax.push_back(j);	}
+			if(vmax>0 && vmin==0)	{	imax.push_back(i);	jmax.push_back(j);	}
+		}
+		size_t nn = imax.size();
+		if(nn>0)
+		{
+			res = new mglData(2,nn);
+			for(size_t i=0;i<nn;i++)
+			{	res->a[2*i] = imax[i]/(n-1.);	res->a[2*i+1] = jmax[i]/(m-1.);	}
+		}
+	}
+	else if(n>3 && m>3 && l>3)
+	{
+		std::vector<mreal> imax, jmax;
+		for(long k=1;k<l-1;k++)	for(long j=1;j<m-1;j++)	for(long i=1;i<n-1;i++)
+		{
+			mreal v = dat->v(i,j,k);
+			long di[] = {-1,0,1,-1,0,1,-1,0,1,		-1,0,1,-1,1,-1,0,1,	-1,0,1,-1,0,1,-1,0,1};
+			long dj[] = {-1,-1,-1,0,0,0,1,1,1,		-1,-1,-1,0,0,1,1,1,	-1,-1,-1,0,0,0,1,1,1};
+			long dk[] = {-1,-1,-1,-1,-1,-1,-1,-1,-1, 0,0,0,0,0,0,0,0,	1,1,1,1,1,1,1,1,1}, vmax=0, vmin=0;
+			for(int ii=0;ii<26;ii++)
+			{
+				mreal u = dat->v(i+di[ii],j+dj[ii],k+dk[ii]);
+				if(mgl_isnan(u))	{	vmax=vmin=0;	break;	}
+				if(v < u)	vmin++;
+				if(v > u)	vmax++;
+			}
+			if(vmin>0 && vmax==0)	{	imax.push_back(i);	jmax.push_back(j);	kmax.push_back(k);	}
+			if(vmax>0 && vmin==0)	{	imax.push_back(i);	jmax.push_back(j);	kmax.push_back(k);	}
+		}
+		size_t nn = imax.size();
+		if(nn>0)
+		{	
+			res = new mglData(3,nn);
+			for(size_t i=0;i<nn;i++)
+			{	res->a[3*i] = imax[i]/(n-1.);	res->a[3*i+1] = jmax[i]/(m-1.);	res->a[3*i+2] = kmax[i]/(l-1.);	}
+		}
+	}
+	return res;
+}
+uintptr_t MGL_EXPORT mgl_data_minmax_(uintptr_t *d)
+{	return uintptr_t(mgl_data_minmax(_DT_));	}
+//-----------------------------------------------------------------------------
 HMDT MGL_EXPORT mgl_data_momentum(HCDT dat, char dir, const char *how)
 {
 	if(!how || !(*how) || !strchr("xyz",dir))	return 0;
@@ -1151,3 +1229,78 @@ uintptr_t MGL_EXPORT mgl_data_section_(uintptr_t *d, uintptr_t *ids, const char
 uintptr_t MGL_EXPORT mgl_data_section_val_(uintptr_t *d, int *id, const char *dir, mreal *val,int)
 {	return uintptr_t(mgl_data_section_val(_DT_,*id,dir[0],*val));	}
 //-----------------------------------------------------------------------------
+void MGL_NO_EXPORT mgl_closest(mreal *res, long n, long i0, long i1, HCDT a, HCDT b)
+{
+	mreal *rr = new mreal[n*n];
+	for(long k0=0;k0<n;k0++)	for(long k1=0;k1<n;k1++)
+		rr[k0+n*k1] = hypot(a->vthr(k0+i0)-a->vthr(k1+i1), b->vthr(k0+i0)-b->vthr(k1+i1));
+	std::set<long> ids, idk;
+	for(long k=0;k<n;k++)	{	ids.insert(k);	idk.insert(k);	}
+	for(long k=0;k<n;k++)
+	{
+		long k0=-1,k1=-1;
+		mreal rm = INFINITY;
+		for(long kk=0;kk<n*n;kk++)
+			if(rr[kk]<rm)	{	rm=rr[kk];	k0=kk%n;	k1=kk/n;	}
+		if(k0>=0)
+		{
+			for(long i=0;i<n;i++)	rr[i+k1*n] = rr[k0+i*n] = NAN;
+			long kk = long(0.5+res[k1+i1]);	res[k0+i0] = kk;
+			ids.erase(kk);	idk.erase(k0);
+		}
+		else
+		{
+			long kk=*(ids.begin()), ik = *(idk.begin());
+			res[ik+i0] = kk;
+			ids.erase(kk);	idk.erase(ik);
+		}
+	}
+	delete []rr;
+}
+HMDT MGL_EXPORT mgl_data_connect(HCDT a, HCDT b)
+{
+	int nx = a->GetNx(), ny = a->GetNy(), nz = a->GetNz();
+	HMDT res = new mglData(nx,ny,nz);
+	for(long j=0;j<ny*nz;j++)	for(long i=0;i<nx;i++)	res->a[i+nx*j] = i;
+	for(long j=0;j<nz;j++)
+	{
+		if(j>0)
+		{
+			long i0 = nx*(ny-1+ny*j);
+			mgl_closest(res->a, nx, i0, i0-nx*ny, a, b);
+		}
+		for(long i=ny-1;i>0;i--)	// TODO optimized for QHCU_dh case only!!!
+		{
+			long i0 = nx*(i+ny*j);
+			mgl_closest(res->a, nx, i0-nx, i0, a, b);
+		}
+	}
+	return res;
+}
+//-----------------------------------------------------------------------------
+uintptr_t MGL_EXPORT mgl_data_connect_(uintptr_t *a, uintptr_t *b)
+{	return uintptr_t(mgl_data_connect(_DA_(a),_DA_(b)));	}
+//-----------------------------------------------------------------------------
+void MGL_EXPORT mgl_data_connect_r(HMDT a, HMDT b)
+{
+	int nx = a->GetNx(), ny = a->GetNy(), nz = a->GetNz();
+	HMDT res = mgl_data_connect(a,b);
+	mreal *buf = new mreal[2*nx];
+	for(long j=0;j<ny*nz;j++)
+	{
+		long i0 = nx*j;
+		memcpy(buf,a->a+i0,nx*sizeof(mreal));
+		memcpy(buf+nx,b->a+i0,nx*sizeof(mreal));
+		for(long i=0;i<nx;i++)
+		{
+			long i1 = res->a[i0+i];
+			a->a[i0+i1] = buf[i];
+			b->a[i0+i1] = buf[i+nx];
+		}
+	}
+	delete []buf;	delete res;
+}
+//-----------------------------------------------------------------------------
+void MGL_EXPORT mgl_data_connect_r_(uintptr_t *a, uintptr_t *b)
+{	mgl_data_connect_r(_DM_(a),_DM_(b));	}
+//-----------------------------------------------------------------------------
