@@ -20,7 +20,7 @@
 #include <time.h>
 #include <ctype.h>
 
-#include "mgl2/data_cf.h"
+#include "mgl2/data.h"
 #include "mgl2/eval.h"
 
 #if MGL_HAVE_GSL
@@ -187,13 +187,16 @@ double MGL_EXPORT mgl_rnd_()	{	return mgl_rnd();	}
 //-----------------------------------------------------------------------------
 mglFormula::~mglFormula()
 {
-	if(Left) delete Left;
-	if(Right) delete Right;
+	if(tmp)		delete tmp;
+	if(Left)	delete Left;
+	if(Right)	delete Right;
 }
 //-----------------------------------------------------------------------------
 // Formula constructor (automatically parse and "compile" formula)
 mglFormula::mglFormula(const char *string)
 {
+	dat = tmp = NULL;
+	dx1=dy1=dz1=0;	dx2=dy2=dz2=1;
 #if MGL_HAVE_GSL
 	gsl_set_error_handler_off();
 #endif
@@ -214,6 +217,21 @@ mglFormula::mglFormula(const char *string)
 		len-=2;	str[len]=0;
 	}
 	len=strlen(str);
+	if(str[0]==':' && str[1]!=0)		//	this data file for interpolation
+	{
+		double sx1,sx2,sy1,sy2,sz1,sz2;
+		char *buf = strchr(str+1,':');
+		if(buf && *buf)
+		{
+			*buf = 0;
+			int r = sscanf(buf+1,"%lg:%lg:%lg:%lg:%lg:%lg",&sx1,&sx2,&sy1,&sy2,&sz1,&sz2);
+			if(r>1 && sx1!=sx2)	{	dx1=sx1;	dx2=sx2;	}
+			if(r>3 && sy1!=sy2)	{	dy1=sy1;	dy2=sy2;	}
+			if(r>5 && sz1!=sz2)	{	dz1=sz1;	dz2=sz2;	}
+		}
+		dat = tmp = new mglData(str+1);
+		delete []str;	return;
+	}
 	n=mglFindInText(str,"&|");				// lowest priority -- logical
 	if(n>=0)
 	{
@@ -551,6 +569,13 @@ static const func_1 f1[EQ_SN-EQ_SIN] = {sin,cos,tan,asin,acos,atan,sinh,cosh,tan
 // evaluation of embedded (included) expressions
 mreal mglFormula::CalcIn(const mreal *a1) const
 {
+	if(dat)
+	{
+		mreal x = (a1['x'-'a']-dx1)*(dat->GetNx()-1)/(dx2-dx1);
+		mreal y = (a1['y'-'a']-dy1)*(dat->GetNy()-1)/(dy2-dy1);
+		mreal z = (a1['z'-'a']-dz1)*(dat->GetNz()-1)/(dz2-dz1);
+		return mgl_data_spline(dat,x,y,z);
+	}
 	if(Kod<EQ_LT)
 	{
 		if(Kod==EQ_RND)	return mgl_rnd();
@@ -668,6 +693,18 @@ static const func_1 f11[EQ_SN-EQ_SIN] = {cos,cos_d,tan_d,asin_d,acos_d,atan_d,co
 // evaluation of derivative of embedded (included) expressions
 mreal mglFormula::CalcDIn(int id, const mreal *a1) const
 {
+	if(dat)
+	{
+		mreal x = (a1['x'-'a']-dx1)*(dat->GetNx()-1)/(dx2-dx1);
+		mreal y = (a1['y'-'a']-dy1)*(dat->GetNy()-1)/(dy2-dy1);
+		mreal z = (a1['z'-'a']-dz1)*(dat->GetNz()-1)/(dz2-dz1);
+		mreal dx,dy,dz, res=0;
+		mgl_data_spline_ext(dat,x,y,z,&dx,&dy,&dz);
+		if(id=='x'-'a')	res = dx/(dat->GetNx()-1)*(dx2-dx1);
+		if(id=='y'-'a')	res = dy/(dat->GetNy()-1)*(dy2-dy1);
+		if(id=='z'-'a')	res = dz/(dat->GetNz()-1)*(dz2-dz1);
+		return res;
+	}
 	if(Kod==EQ_A && id==(int)Res)	return 1;
 	else if(Kod<EQ_LT)	return 0;
 	double a = Left->CalcIn(a1), d = Left->CalcDIn(id,a1);
@@ -737,13 +774,13 @@ int MGL_LOCAL_PURE mglFindInText(const char *str, const char *lst)
 //-----------------------------------------------------------------------------
 HMEX MGL_EXPORT mgl_create_expr(const char *expr)	{	return new mglFormula(expr);	}
 void MGL_EXPORT mgl_delete_expr(HMEX ex)	{	if(ex)	delete ex;	}
-double MGL_EXPORT mgl_expr_eval(HMEX ex, double x, double y,double z)
+double MGL_EXPORT_PURE mgl_expr_eval(HMEX ex, double x, double y,double z)
 {	return ex->Calc(x,y,z);	}
-double MGL_EXPORT mgl_expr_eval_v(HMEX ex, mreal *var)
+double MGL_EXPORT_PURE mgl_expr_eval_v(HMEX ex, mreal *var)
 {	return ex->Calc(var);	}
-double MGL_EXPORT mgl_expr_diff(HMEX ex, char dir, double x, double y,double z)
+double MGL_EXPORT_PURE mgl_expr_diff(HMEX ex, char dir, double x, double y,double z)
 {	return ex->CalcD(dir,x,y,z);	}
-double MGL_EXPORT mgl_expr_diff_v(HMEX ex, char dir, mreal *var)
+double MGL_EXPORT_PURE mgl_expr_diff_v(HMEX ex, char dir, mreal *var)
 {	return ex->CalcD(var, dir);		}
 //-----------------------------------------------------------------------------
 uintptr_t MGL_EXPORT mgl_create_expr_(const char *expr, int l)
@@ -751,8 +788,8 @@ uintptr_t MGL_EXPORT mgl_create_expr_(const char *expr, int l)
 	uintptr_t res = uintptr_t(mgl_create_expr(s));
 	delete []s;	return res;	}
 void MGL_EXPORT mgl_delete_expr_(uintptr_t *ex)	{	mgl_delete_expr((HMEX)ex);	}
-double MGL_EXPORT mgl_expr_eval_(uintptr_t *ex, mreal *x, mreal *y, mreal *z)
+double MGL_EXPORT_PURE mgl_expr_eval_(uintptr_t *ex, mreal *x, mreal *y, mreal *z)
 {	return mgl_expr_eval((HMEX) ex, *x,*y,*z);		}
-double MGL_EXPORT mgl_expr_diff_(uintptr_t *ex, const char *dir, mreal *x, mreal *y, mreal *z, int)
+double MGL_EXPORT_PURE mgl_expr_diff_(uintptr_t *ex, const char *dir, mreal *x, mreal *y, mreal *z, int)
 {	return mgl_expr_diff((HMEX) ex, *dir,*x,*y,*z);	}
 //-----------------------------------------------------------------------------
