@@ -18,8 +18,7 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 #include <time.h>
-#include "mgl2/data_cf.h"
-#include "mgl2/datac_cf.h"
+#include "mgl2/datac.h"
 #include "mgl2/evalc.h"
 #if MGL_HAVE_GSL
 #include <gsl/gsl_sf.h>
@@ -76,13 +75,16 @@ int MGL_LOCAL_PURE mglFindInText(const char *str, const char *lst);
 //-----------------------------------------------------------------------------
 mglFormulaC::~mglFormulaC()
 {
-	if(Left) delete Left;
-	if(Right) delete Right;
+	if(tmp)		delete tmp;
+	if(Left)	delete Left;
+	if(Right)	delete Right;
 }
 //-----------------------------------------------------------------------------
 // Formula constructor (automatically parse and "compile" formula)
 mglFormulaC::mglFormulaC(const char *string)
 {
+	dat = tmp = NULL;
+	dx1=dy1=dz1=0;	dx2=dy2=dz2=1;
 	Error=0;
 	Left=Right=0;
 	Res=0; Kod=0;
@@ -100,6 +102,21 @@ mglFormulaC::mglFormulaC(const char *string)
 		len-=2;	str[len]=0;
 	}
 	len=strlen(str);
+	if(str[0]==':' && str[1]!=0)		//	this data file for interpolation
+	{
+		double sx1,sx2,sy1,sy2,sz1,sz2;
+		char *buf = strchr(str+1,':');
+		if(buf && *buf)
+		{
+			*buf = 0;
+			int r = sscanf(buf+1,"%lg:%lg:%lg:%lg:%lg:%lg",&sx1,&sx2,&sy1,&sy2,&sz1,&sz2);
+			if(r>1 && sx1!=sx2)	{	dx1=sx1;	dx2=sx2;	}
+			if(r>3 && sy1!=sy2)	{	dy1=sy1;	dy2=sy2;	}
+			if(r>5 && sz1!=sz2)	{	dz1=sz1;	dz2=sz2;	}
+		}
+		dat = tmp = new mglDataC(str+1);
+		delete []str;	return;
+	}
 	n=mglFindInText(str,"<>=");				// low priority -- conditions
 	if(n>=0)
 	{
@@ -283,6 +300,13 @@ static const func_1 f1[EQ_LAST-EQ_SIN] = {sinc,cosc,tanc,asinc,acosc,atanc,sinhc
 // evaluation of embedded (included) expressions
 dual mglFormulaC::CalcIn(const dual *a1) const
 {
+	if(dat)
+	{
+		mreal x = (real(a1['x'-'a'])-dx1)*(dat->GetNx()-1)/(dx2-dx1);
+		mreal y = (real(a1['y'-'a'])-dy1)*(dat->GetNy()-1)/(dy2-dy1);
+		mreal z = (real(a1['z'-'a'])-dz1)*(dat->GetNz()-1)/(dz2-dz1);
+		return mgl_datac_spline(dat,x,y,z);
+	}
 	if(Kod<EQ_LT)
 	{
 		if(Kod==EQ_RND)	return mgl_rnd();
@@ -316,7 +340,7 @@ dual MGL_LOCAL_CONST mgl_ipowc_c(dual x,int n)
 }
 cmdual MGL_EXPORT_CONST mgl_ipowc(mdual x,int n)
 {	return mdual(mgl_ipowc_c(x,n));	}
-cmdual MGL_EXPORT mgl_ipowc_(mdual *x,int *n)	{	return mgl_ipowc(*x,*n);	}
+cmdual MGL_EXPORT_PURE mgl_ipowc_(mdual *x,int *n)	{	return mgl_ipowc(*x,*n);	}
 //-----------------------------------------------------------------------------
 HAEX MGL_EXPORT mgl_create_cexpr(const char *expr)	{	return new mglFormulaC(expr);	}
 uintptr_t MGL_EXPORT mgl_create_cexpr_(const char *expr, int l)
