@@ -258,7 +258,7 @@ HADT mglApplyOperDivC(std::wstring a1, std::wstring a2, mglParser *arg, const st
 	mgl_delete_datac(d);	return r;
 }
 //-----------------------------------------------------------------------------
-bool mglCheck(std::wstring str)
+bool MGL_LOCAL_PURE mglCheck(std::wstring str)
 {
 	long s = 0,i,n=str.length();
 	for(i=0;i<n;i++)
@@ -270,7 +270,7 @@ bool mglCheck(std::wstring str)
 	return (s==0) ? true : false;
 }
 //-----------------------------------------------------------------------------
-long mglFindInText(const std::wstring &str,const char *lst)
+long MGL_LOCAL_PURE mglFindInText(const std::wstring &str,const char *lst)
 {
 	long l=0,r=0;
 	for(long i=str.length()-1;i>=0;i--)
@@ -366,6 +366,14 @@ HMDT MGL_NO_EXPORT mglFormulaCalc(std::wstring str, mglParser *arg, const std::v
 	long n,len=str.length();
 	if(str[0]=='(' && mglCheck(str.substr(1,len-2)))	// remove braces
 	{	str = str.substr(1,len-2);	len-=2;	}
+	if(str[0]==':' && str[1]!=0)		//	this data file
+	{
+		size_t l=str.length()+1;
+		char *buf = new char[l];	memset(buf,0,l);
+		for(size_t i=1;str[i]!=0 && str[i]!=':' && i<l;i++)	buf[i-1]=str[i];
+		HMDT res = new mglData(buf);	delete []buf;
+		return res;
+	}
 	if(str[0]=='[')	// this is manual subdata
 	{
 		long i, j, br=0,k;
