@@ -185,13 +185,26 @@ int static mgls_crange(mglGraph *gr, long , mglArg *a, const char *k, const char
 	return res;
 }
 //-----------------------------------------------------------------------------
-int static mgls_ctick(mglGraph *gr, long , mglArg *a, const char *k, const char *)
+int static mgls_ctick(mglGraph *gr, long n, mglArg *a, const char *k, const char *)
 {
 	int res=0;
 	if(!strcmp(k,"s"))	gr->SetTickTempl('c',a[0].s.w);
 	else if(!strcmp(k,"n"))	gr->SetTicks('c',a[0].v,0,0);
 	else if(!strcmp(k,"ns"))	gr->SetTicks('c',a[0].v,0,0,a[1].s.w);
-	else res = 1;
+	else if(!strcmp(k,"ds"))	gr->SetTicksVal('c', *(a[0].d), a[1].s.w);
+	else if(!strcmp(k,"dsn"))	gr->SetTicksVal('c', *(a[0].d), a[1].s.w, a[2].v);
+	else if(!strncmp(k,"ns",2))
+	{
+		std::wstring s;
+		std::vector<mreal> v;
+		for(long i=0;i<n/2;i++)
+		{
+			if(a[2*i].type==2 && a[2*i+1].type==1)
+			{	v.push_back(a[2*i].v);	s += std::wstring(a[2*i+1].s.w)+L"\n";	}
+			else	break;
+		}
+		gr->SetTicksVal('c',mglDataS(v),s.c_str(),v.size()==1?true:false);
+	}	else res = 1;
 	return res;
 }
 //-----------------------------------------------------------------------------
@@ -337,6 +350,10 @@ int static mgls_mask(mglGraph *gr, long , mglArg *a, const char *k, const char *
 	int res=0;
 	if(!strcmp(k,"sn"))	gr->SetMask(a[0].s[0],a[1].v);
 	else if(!strcmp(k,"ss"))	gr->SetMask(a[0].s[0],a[1].s.s);
+	else if(!strcmp(k,"snn"))
+	{	gr->SetMask(a[0].s[0],a[1].v);	gr->SetMaskAngle(mgl_int(a[2].v));	}
+	else if(!strcmp(k,"ssn"))
+	{	gr->SetMask(a[0].s[0],a[1].s.s);gr->SetMaskAngle(mgl_int(a[2].v));	}
 	else if(!strcmp(k,"n"))		gr->SetMaskAngle(mgl_int(a[0].v));
 	else res = 1;
 	return res;
@@ -838,12 +855,12 @@ mglCommand mgls_set_cmd[] = {
 	{"view",_("Change view angles - use 'rotate' for plot rotation"),"view tetz tetx [tety]", mgls_view ,5},
 	{"write",_("Write current image to graphical file"),"write ['fname']", mgls_write ,2},
 	{"xrange",_("Set range for x-axis"),"xrange Dat [add]|x1 x2 [add]", mgls_xrange ,14},
-	{"xtick",_("Set ticks for x-axis"),"xtick dx ['factor']|dx sx ['factor']|dx sx tx ['factor']|'tmpl'|Xdat 'lbl' [add]|v1 'lbl1' ...", mgls_xtick,14},
+	{"xtick",_("Set ticks for x-axis"),"xtick dx sx ['factor']|dx sx tx ['factor']|'tmpl'|Xdat 'lbl' [add]|v1 'lbl1' ...", mgls_xtick,14},
 	{"yrange",_("Set range for y-axis"),"yrange Dat [add]|y1 y2 [add]", mgls_yrange,14},
-	{"ytick",_("Set ticks for y-axis"),"ytick dy ['factor']|dy sy ['factor']|dy sy ty ['factor']|'tmpl'|Ydat 'lbl' [add]|v1 'lbl1' ...", mgls_ytick,14},
+	{"ytick",_("Set ticks for y-axis"),"ytick dy sy ['factor']|dy sy ty ['factor']|'tmpl'|Ydat 'lbl' [add]|v1 'lbl1' ...", mgls_ytick,14},
 	{"zoom",_("Zoom plot region"),"zoom x1 x2 y1 y2", mgls_zoom,5},
 	{"zoomaxis",_("Zoom axis range"),"zoomaxis x1 x2|x1 y1 x2 y2|x1 y1 z1 x2 y2 z2|x1 y1 z1 c1 x2 y2 z2 c2", mgls_zoomaxis,14},
 	{"zrange",_("Set range for z-axis"),"yrange Dat [add]|z1 z2 [add]", mgls_zrange ,14},
-	{"ztick",_("Set ticks for z-axis"),"ztick dz ['factor']|dz sz ['factor']|dz sz tz ['factor']|'tmpl'|Zdat 'lbl' [add]|v1 'lbl1' ...", mgls_ztick,14},
+	{"ztick",_("Set ticks for z-axis"),"ztick dz sz ['factor']|dz sz tz ['factor']|'tmpl'|Zdat 'lbl' [add]|v1 'lbl1' ...", mgls_ztick,14},
 {"","","",NULL,0}};
 //-----------------------------------------------------------------------------
