@@ -20,8 +20,8 @@
 #include "mgl2/font.h"
 
 /// Table of LaTeX symbols and its UTF8 codes. This array MUST BE sorted!!!
-MGL_EXPORT long mgl_tex_num=1924;
-MGL_EXPORT mglTeXsymb mgl_tex_symb[] = {
+const size_t mgl_tex_num=1924;
+const mglTeXsymb mgl_tex_symb[] = {
 	{0x23, L"#"},
 	{0x25, L"%"},
 	{0x26, L"&"},
