@@ -172,6 +172,20 @@ void MGL_EXPORT mgl_get_last_mouse_pos(HMGL gr, mreal *x, mreal *y, mreal *z)
 {	mglCanvasWnd *g = dynamic_cast<mglCanvasWnd *>(gr);
 	mglPoint p;	if(g)	p=g->GetMousePos();
 	*x=p.x;	*y=p.y;	*z=p.z;	}
+MGL_EXPORT void *mgl_wnd_window(HMGL gr)
+{	mglCanvasWnd *g = dynamic_cast<mglCanvasWnd *>(gr);	return g?g->Window():NULL;	}
+MGL_EXPORT void *mgl_wnd_widget(HMGL gr)
+{	mglCanvasWnd *g = dynamic_cast<mglCanvasWnd *>(gr);	return g?g->Widget():NULL;	}
+/// Move window to given position
+void MGL_EXPORT mgl_wnd_move(HMGL gr, int x, int y)
+{	mglCanvasWnd *g = dynamic_cast<mglCanvasWnd *>(gr);	if(g)	g->WndMove(x,y);	}
+void MGL_EXPORT mgl_wnd_move_(uintptr_t *gr, int *x, int *y)
+{	mglCanvasWnd *g = dynamic_cast<mglCanvasWnd *>((HMGL)(*gr));	if(g)	g->WndMove(*x,*y);	}
+/// Change window sizes
+void MGL_EXPORT mgl_wnd_size(HMGL gr, int w, int h)
+{	mglCanvasWnd *g = dynamic_cast<mglCanvasWnd *>(gr);	if(g)	g->WndSize(w,h);	}
+void MGL_EXPORT mgl_wnd_size_(uintptr_t *gr, int *w, int *h)
+{	mglCanvasWnd *g = dynamic_cast<mglCanvasWnd *>((HMGL)(*gr));	if(g)	g->WndSize(*w,*h);	}
 //-----------------------------------------------------------------------------
 void MGL_EXPORT mgl_wnd_toggle_alpha_(uintptr_t *gr)
 {	mglCanvasWnd *g = dynamic_cast<mglCanvasWnd *>((HMGL)(*gr));
@@ -381,6 +395,15 @@ void MGL_EXPORT mgl_parse_animation(const wchar_t *text, std::vector<std::wstrin
 	mgl_parse_comments(text, a1, a2, da, anim, ids, par);
 }
 //-----------------------------------------------------------------------------
+#undef _GR_
+#define _GR_	((mglCanvas *)(*gr))
+void MGL_EXPORT mgl_wnd_set_delay(HMGL gr, double dt)
+{	mglCanvas *g = dynamic_cast<mglCanvas *>(gr);	if(g)	g->SetDelay(dt);	}
+double MGL_EXPORT_PURE mgl_wnd_get_delay(HMGL gr)
+{	mglCanvas *g = dynamic_cast<mglCanvas *>(gr);	return g?g->GetDelay():0;	}
+void MGL_EXPORT mgl_wnd_set_delay_(uintptr_t *gr, mreal *dt)	{	_GR_->SetDelay(*dt);	}
+double MGL_EXPORT_PURE mgl_wnd_get_delay_(uintptr_t *gr)	{	return _GR_->GetDelay();	}
+//-----------------------------------------------------------------------------
 MGL_EXPORT const char *mgl_hints[] = {
 	_("You can shift axis range by pressing middle button and moving mouse. Also, you can zoom in/out axis range by using mouse wheel."),
 	_("You can rotate/shift/zoom whole plot by mouse. Just press 'Rotate' toolbutton, click image and hold a mouse button: left button for rotation, right button for zoom/perspective, middle button for shift."),
