@@ -61,6 +61,10 @@ using mglCanvasWnd::Window;
 	void Animation();	///< Run animation (I'm too lasy to change it)
 	void MakeDialog(const char *ids, char const * const *args, const char *title="")
 	{	if(GetNumFig()==1)	mgl->dialog(ids,args,title);	}
+	void *Window()	{return Wnd;}	///< Return pointer to widget (Fl_Window*) used for plotting
+	void *Widget()	{return mgl;}	///< Return pointer to widget (Fl_MGLView*) used for plotting
+	void WndSize(int w, int h)	{	Wnd->size(w,h);	}	///< Resize window
+	void WndMove(int x, int y)	{	Wnd->position(x,y);	}	///< Move window
 };
 //-----------------------------------------------------------------------------
 void MGL_EXPORT mgl_ask_fltk(const wchar_t *quest, wchar_t *res)
@@ -1045,7 +1049,7 @@ HMGL MGL_EXPORT mgl_create_graph_fltk(int (*draw)(HMGL gr, void *p), const char
 	g->mgl->FMGL->set_handle_key(true);
 	return g;
 }
-void* mgl_fltk_widget(HMGL gr)
+MGL_EXPORT_PURE void* mgl_fltk_widget(HMGL gr)
 {
 	mglCanvasFL *g = dynamic_cast<mglCanvasFL *>(gr);
 	return g?g->mgl:NULL;
