@@ -73,6 +73,10 @@ using mglCanvasWnd::Window;
 	void GotoFrame(int d);	///< Show arbitrary frame (use relative step)
 	void Animation();		///< Run slideshow (animation) of frames
 	void MakeDialog(const char *ids, char const * const *args, const char *title=""){}	// TODO
+	void *Window()	{return Wnd;}	///< Return pointer to widget (QMainWindow*) used for plotting
+	void *Widget()	{return QMGL;}	///< Return pointer to widget (QMathGL*) used for plotting
+	void WndSize(int w, int h)	{	Wnd->resize(w,h);	}	///< Resize window
+	void WndMove(int x, int y)	{	Wnd->move(x,y);	}	///< Move window
 
 
 protected:
@@ -1298,7 +1302,7 @@ HMGL MGL_EXPORT mgl_create_graph_qt(int (*draw)(HMGL gr, void *p), const char *t
 	g->Window(0,0,draw,title,par,load);
 	return g;
 }
-void* mgl_qt_widget(HMGL gr)
+MGL_EXPORT_PURE void* mgl_qt_widget(HMGL gr)
 {
 	mglCanvasQT *g = dynamic_cast<mglCanvasQT *>(gr);
 	return g?g->QMGL:NULL;
